StaticGraphMeta

Struct StaticGraphMeta 

pub struct StaticGraphMeta {
Show 23 fields pub graphid: String, pub author: Option<String>, pub cards: Option<u32>, pub cards_x_nodes_x_widgets: Option<u32>, pub color: Option<String>, pub description: Option<StaticTranslatableString>, pub edges: Option<u32>, pub iconclass: Option<String>, pub is_editable: Option<bool>, pub isresource: Option<bool>, pub jsonldcontext: Option<Value>, pub name: Option<StaticTranslatableString>, pub nodegroups: Option<u32>, pub nodes: Option<u32>, pub ontology_id: Option<Vec<String>>, pub publication: Option<HashMap<String, Option<String>>>, pub relatable_resource_model_ids: Vec<String>, pub resource_2_resource_constraints: Option<Vec<Value>>, pub root: Option<Box<StaticNode>>, pub slug: Option<String>, pub subtitle: Option<StaticTranslatableString>, pub version: Option<String>, pub extra_fields: HashMap<String, Value>,
}
Lightweight metadata about a graph, without the full nodes/edges arrays. Used for listing graphs without loading all their data.

Fields

graphid: Stringauthor: Option<String>cards: Option<u32>cards_x_nodes_x_widgets: Option<u32>color: Option<String>description: Option<StaticTranslatableString>edges: Option<u32>iconclass: Option<String>is_editable: Option<bool>isresource: Option<bool>jsonldcontext: Option<Value>

JSON-LD context - can be a string (URL) or an object (inline context)

name: Option<StaticTranslatableString>nodegroups: Option<u32>nodes: Option<u32>ontology_id: Option<Vec<String>>

Ontology IDs used by this graph. Accepts a single string or an array of strings on the wire.

publication: Option<HashMap<String, Option<String>>>relatable_resource_model_ids: Vec<String>resource_2_resource_constraints: Option<Vec<Value>>root: Option<Box<StaticNode>>slug: Option<String>subtitle: Option<StaticTranslatableString>version: Option<String>extra_fields: HashMap<String, Value>

Extra fields not explicitly defined

Implementations

Source

impl StaticGraphMeta

pub fn display_name(&self) -> String

Get the display name of the graph

pub fn display_subtitle(&self) -> String

Get the display subtitle

pub fn display_description(&self) -> String

Get the display description

pub fn display_author(&self) -> String

Get the author