pub struct StaticTranslatableString {
pub translations: HashMap<String, String>,
pub lang: String,
}Expand description
A string with translations for multiple languages
Fields
translations: HashMap<String, String>lang: StringImplementations
Sourceimpl StaticTranslatableString
impl StaticTranslatableString
Sourcepub fn from_translations(
translations: HashMap<String, String>,
default_lang: Option<String>,
) -> Self
pub fn from_translations( translations: HashMap<String, String>, default_lang: Option<String>, ) -> Self
Create a new translatable string from a map of translations
Sourcepub fn from_string(s: &str) -> Self
pub fn from_string(s: &str) -> Self
Create from a simple string (assumes English)
Sourcepub fn get(&self, lang: &str) -> String
pub fn get(&self, lang: &str) -> String
Get the string for a specific language, falling back to any available
Sourcepub fn to_string_default(&self) -> String
pub fn to_string_default(&self) -> String
Get the string using the default language