GraphMutation

Enum GraphMutation 

pub enum GraphMutation {
Show 27 variants AddNode(AddNodeParams), AddNodegroup(AddNodegroupParams), AddEdge(AddEdgeParams), AddCard(AddCardParams), AddWidgetToCard(AddWidgetParams), AddSubgraph(AddSubgraphParams), UpdateSubgraph(UpdateSubgraphParams), ConceptChangeCollection(ConceptChangeCollectionParams), DeleteCard(DeleteCardParams), DeleteWidget(DeleteWidgetParams), AddFunction(AddFunctionParams), SetDescriptorFunction(SetDescriptorFunctionParams), DeleteFunction(DeleteFunctionParams), DeleteNode(DeleteNodeParams), DeleteNodegroup(DeleteNodegroupParams), UpdateNode(UpdateNodeParams), ChangeNodeType(ChangeNodeTypeParams), ChangeCardinality(ChangeCardinalityParams), RenameNode(RenameNodeParams), RenameCard(RenameCardParams), RealignCardFromNode(RealignCardFromNodeParams), RenameGraph(RenameGraphParams), SetDescriptorTemplate(SetDescriptorTemplateParams), CreateGraph(CreateGraphParams), CoppiceSubgraph(CoppiceSubgraphParams), UpdateWidgetConfig(UpdateWidgetConfigParams), Extension(ExtensionMutationParams),
}
A graph mutation operation (Command pattern)

Variants



AddNode(AddNodeParams)



AddNodegroup(AddNodegroupParams)



AddEdge(AddEdgeParams)



AddCard(AddCardParams)



AddWidgetToCard(AddWidgetParams)



AddSubgraph(AddSubgraphParams)



UpdateSubgraph(UpdateSubgraphParams)



ConceptChangeCollection(ConceptChangeCollectionParams)



DeleteCard(DeleteCardParams)



DeleteWidget(DeleteWidgetParams)



AddFunction(AddFunctionParams)



SetDescriptorFunction(SetDescriptorFunctionParams)

Set the descriptor function for this graph, removing any other descriptor functions



DeleteFunction(DeleteFunctionParams)



DeleteNode(DeleteNodeParams)



DeleteNodegroup(DeleteNodegroupParams)



UpdateNode(UpdateNodeParams)



ChangeNodeType(ChangeNodeTypeParams)



ChangeCardinality(ChangeCardinalityParams)



RenameNode(RenameNodeParams)



RenameCard(RenameCardParams)

Rename/update a card’s display name and description



RealignCardFromNode(RealignCardFromNodeParams)

Realign a card and widget label to match the current node name



RenameGraph(RenameGraphParams)

Rename/update graph metadata (name, description, subtitle, author)



SetDescriptorTemplate(SetDescriptorTemplateParams)

Set a descriptor template (name, slug, etc.) on the graph’s descriptor function



CreateGraph(CreateGraphParams)

Create a new graph from scratch (only valid as first mutation in apply_mutations_create)



CoppiceSubgraph(CoppiceSubgraphParams)

Set sourcebranchpublication_id on a subtree rooted at a given alias



UpdateWidgetConfig(UpdateWidgetConfigParams)

Merge config keys into an existing widget’s config (found by node alias)



Extension(ExtensionMutationParams)

Extension mutation - delegated to a registered handler

Implementations

Source

impl GraphMutation

pub fn conformance(&self) -> MutationConformance

Get the conformance level for this mutation