pub struct MutatorOptions {
pub autocreate_card: bool,
pub autocreate_widget: bool,
pub ontology_validator: Option<OntologyValidator>,
pub skip_publication: bool,
}Expand description
Options for the GraphMutator
Fields
autocreate_card: boolAutomatically create cards for new nodegroups
autocreate_widget: boolAutomatically add default widgets to cards
ontology_validator: Option<OntologyValidator>Optional ontology validator for class/property validation
skip_publication: boolSkip stamping a new publication ID on the graph. Useful when applying collection assignments to a branch that has already been captured by a resource model via add_subgraph.